chiark / gitweb /
Expunge revision histories in files.
[mgLib] / msg.c
diff --git a/msg.c b/msg.c
index cbfede111f189429f8fe43035e2e816d33d2212c..d574060de47d1134257af97e67586b5918d2059f 100644 (file)
--- a/msg.c
+++ b/msg.c
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
- * $Id: msg.c,v 1.5 1999/05/05 18:52:45 mdw Exp $
+ * $Id: msg.c,v 1.11 2004/04/08 01:36:14 mdw Exp $
  *
  * Display a message and get an answer
  *
  * GNU Library General Public License for more details.
  * 
  * You should have received a copy of the GNU Library General Public
- * License along with mgLib; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * License along with mgLib; if not, write to the Free
+ * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
+ * MA 02111-1307, USA.
  */
 
-/*----- Revision history --------------------------------------------------* 
- *
- * $Log: msg.c,v $
- * Revision 1.5  1999/05/05 18:52:45  mdw
- * Change licensing conditions to LGPL.
- *
- * Revision 1.4  1999/04/29 20:48:13  mdw
- * Add documentation for `msg'.
- *
- * Revision 1.3  1999/03/25 23:36:10  mdw
- * Compile to nothing in absence of GTK, for the benefit of parent packages
- * which contain non-GTK-dependent parts.
- *
- * Revision 1.2  1998/12/15 23:48:06  mdw
- * Use `dstr_putf' for formatting, rather than `sprintf'.
- *
- * Revision 1.1  1998/12/11 09:44:21  mdw
- * Initial version.
- *
- */
-
-#ifdef HAVE_GTK
-
 /*----- Header files ------------------------------------------------------*/
 
 #include <stdarg.h>
@@ -74,8 +52,9 @@ static int creply;
 
 /* --- @msg@ --- *
  *
* Arguments:  @char *buttons@ = the button strings to display
*             @char *msg@ = the message skeleton string
  *
  * Returns:    Index of the button selected.
  *
@@ -104,13 +83,14 @@ static void click(GtkWidget *w, gpointer p)
   gtk_main_quit();
 }
 
-int msg(const char *buttons, const char *msg, ...)
+int msg(const char *title, const char *buttons, const char *msg, ...)
 {
   GtkWidget *dbox, *w;
 
   /* --- Make most of the dialogue box --- */
 
   dbox = gtk_dialog_new();
+  gtk_window_set_title(GTK_WINDOW(dbox), title);
   gtk_signal_connect(GTK_OBJECT(dbox), "delete_event",
                     GTK_SIGNAL_FUNC(close), 0);
   gtk_box_set_homogeneous(GTK_BOX(GTK_DIALOG(dbox)->action_area), 0);  
@@ -118,12 +98,11 @@ int msg(const char *buttons, const char *msg, ...)
   /* --- Set up the message string --- */
 
   {
-    dstr d;
+    dstr d = DSTR_INIT;
     va_list ap;
 
     va_start(ap, msg);
-    dstr_create(&d);
-    dstr_vputf(&d, msg, ap);
+    dstr_vputf(&d, msg, &ap);
     va_end(ap);
     w = gtk_label_new(d.buf);
     gtk_box_pack_start(GTK_BOX(GTK_DIALOG(dbox)->vbox), w, 1, 1, 0);
@@ -140,11 +119,9 @@ int msg(const char *buttons, const char *msg, ...)
     unsigned f = 0;
     int i = 0;
 
-    enum {
-      f_ok = 1,
-      f_cancel = 2,
-      f_mdwfocus = 4
-    };
+#define f_ok 1u
+#define f_cancel 2u
+#define f_mdwfocus 4u
 
     if (*p == '!') {
       f |= f_mdwfocus;
@@ -183,6 +160,9 @@ int msg(const char *buttons, const char *msg, ...)
     if (f & f_mdwfocus)
       mdwfocus(dbox);
 
+#undef f_ok
+#undef f_cancel
+#undef f_mdwfocus
   }
 
   /* --- Ready --- */
@@ -196,7 +176,3 @@ int msg(const char *buttons, const char *msg, ...)
 }
 
 /*----- That's all, folks -------------------------------------------------*/
-
-#else
-  int mgLib_msg = 0;
-#endif
@@ -74,8 +52,9 @@ static int creply;
 /* --- @msg@ --- *
  *
- * Arguments:  @char *buttons@ = the button strings to display
- *             @char *msg@ = the message skeleton string
+ * Arguments:  @const char *title@ = the title for the message box
+ *             @const char *buttons@ = the button strings to display
+ *             @const char *msg@ = the message skeleton string
  *
  * Returns:    Index of the button selected.